# ServiceNow Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/servicenow-integration#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/servicenow-integration#prerequisites)
  * [Communication with ServiceNow](https://help.sap.com/docs/leanix/ea/servicenow-integration#communication-with-servicenow)
  * [Core Concepts](https://help.sap.com/docs/leanix/ea/servicenow-integration#core-concepts)
  * [Sync Mode](https://help.sap.com/docs/leanix/ea/servicenow-integration#sync-mode)
  * [Supported Configurations](https://help.sap.com/docs/leanix/ea/servicenow-integration#supported-configurations)
  * [Default Mapping](https://help.sap.com/docs/leanix/ea/servicenow-integration#default-mapping)
  * [Default Mapping (SAM Pro)](https://help.sap.com/docs/leanix/ea/servicenow-integration#default-mapping-\(sam-pro\))


View all
Fundamentals of the SAP LeanIX integration with ServiceNow (CMDB).
